@@ -1,6 +1,7 @@
 from collections import OrderedDict
 import sys
 import pytest
+import os
 
 import pandas as pd
 import numpy as np
@@ -25,9 +26,14 @@ def test__infer_category():
         assert s2.dtype != 'category'
     except TypeError:  # oh, pandas
         assert True
+    assert s1.equals(s2)
 
-    s1 = pd.Series(range(1000))
-    s2 = paramsurvey.params._coerce_to_category(s1)
+    s1 = pd.Series([[0]] * 1000)  # unhashable type
+    s2 = paramsurvey.params._infer_category(s1)
+    assert s1.equals(s2)
+
+    s1 = pd.Series([0] * 1000)
+    s2 = paramsurvey.params._infer_category(s1)
     assert s2.dtype == 'category'
 
 
@@ -108,7 +114,6 @@ def test_add_column():
         pass
 
 
-
 def params(m, n):
     d = {}
     for a in range(n):
@@ -132,6 +137,9 @@ def test_param_stress():
     # index is an int64, so usage is at least (int64 + 2*int16) = 8 bytes * 25mm = 0.4gbyte
     assert vmem1 - vmem0 < 1.04, 'tight limit that requires int16 type to pass'
 
+    if 'TRAVIS_CPU_ARCH' in os.environ and os.environ['TRAVIS_CPU_ARCH'] == 's390x':
+        return
+
     vmem0 = paramsurvey.utils.vmem()
     psets = params(100, 4)  # 100 million int8
     print('memory')
